<?php

namespace Moneta;

class MonetaSdkReceipt {
    /**
     * Exception messages text
     */
    const EXCEPTION_REQUIRED_ITEM_PARAM = "This item param is required: ";
    const EXCEPTION_REQUIRED_CUSTOMER_PARAM = "This customer param is required: ";
    const EXCEPTION_ARRAY_ITEMS_IS_REQUIRED = "The items array is required";

    public array $items, $customer, $additionalUserProps;
    public string $additionalCheckProp;
    public float $delivery;

    /**
     * @return array
     */
    public function getJsonReceipt() {
        $receipt = [
            'client' => $this->getJsonCustomer(),
            'items' => $this->getJsonItems(),
        ];

        if (isset($this->additionalCheckProp)) {
            $receipt['additionalCheckProp'] = $this->additionalCheckProp;
        }

        if (isset($this->additionalUserProps)) {
            $receipt['additionalUserProps'] = $this->additionalUserProps;
        }

        return $receipt;
    }

    /**
     * @return array
     * @throws MonetaSdkException
     */
    private function getJsonItems() {
        $this->checkReceiptParams();

        foreach ($this->items as $iteration => $item) {
            $receiptItems[] = array_diff([
                'name' => $item['name'],
                'price' => $item['price'],
                'quantity' => $item['quantity'],
                'measure' => $item['measure'] ?? '',
                'paymentMethod' => $item['paymentMethod'] ?? '',
                'paymentObject' => $item['paymentObject'] ?? '',
                'vat' =>  $item['vat'] ?? 'none',
            ], ['']);

            if (isset($item['agentInfo']['payingAgent'])) {
                $receiptItems[$iteration]['agentInfo']['payingAgent'] = [
                    'operation' => $item['agentInfo']['payingAgent']['operation'],
                    'phones' => $item['agentInfo']['payingAgent']['phones']
                ];
            }

            if (isset($item['agentInfo']['supplierInfo'])) {
                $receiptItems[$iteration]['agentInfo']['supplierInfo'] = [
                    'phones' => $item['agentInfo']['supplierInfo']['phones'],
                    'name' => $item['agentInfo']['supplierInfo']['name'],
                    'inn' => $item['agentInfo']['supplierInfo']['inn'],
                ];
            }
        }

        if (isset($this->delivery)) {
            $receiptItems[] = [
                'name' => 'Доставка',
                'price' => $this->delivery,
                'quantity' => 1,
                'vat' => 'none',
                'paymentObject' => 'service'
            ];
        }

        return $receiptItems;
    }

    /**
     * @return array
     * @throws MonetaSdkException
     */
    private function getJsonCustomer() {
        $this->checkReceiptParams(false);

        $customer = [
            'name' => $this->customer['name'] ?? '',
            'inn' => $this->customer['inn'] ?? '',
            'email' => $this->customer['email'],
            'phone' => $this->customer['phone'] ?? '',
        ];

        $customer = array_diff($customer, ['']);

        return $customer;
    }

    /**
     * @return array
     * @throws MonetaSdkException
     */
    public function getXmlItems() {
        $this->checkReceiptParams();

        foreach ($this->items as $iteration => $item) {
            $receiptItems[] = array_diff([
                'name' => $item['name'],
                'price' => $item['price'],
                'quantity' => $item['quantity'],
                'vatTag' => MonetaSdkService::getXmlVat($item['vat'] ?? 'none'),
                'pm' => $item['paymentMethod'] ?? 'full_payment',
                'po' => $item['paymentObject'] ?? 'commodity',
            ]);

            if (isset($item['agentInfo']['type'])) {
                $receiptItems[$iteration]['agentInfo']['type'] = $item['agentInfo']['type'];
            }

            if (isset($item['supplierInfo'])) {
                $receiptItems[$iteration]['supplierInfo'] = [
                    'name' => $item['supplierInfo']['name'],
                    'inn' => $item['supplierInfo']['inn'],
                    'phones' => $item['supplierInfo']['phones'],
                ];
            }
        }

        return json_encode($receiptItems, JSON_UNESCAPED_UNICODE);
    }

    /**
     * @param bool $isItems
     * @throws MonetaSdkException
     */
    private function checkReceiptParams($isItems = true) {
        switch ($isItems) {
            case true:
                if (!isset($this->items)) {
                    throw new MonetaSdkException(self::EXCEPTION_ARRAY_ITEMS_IS_REQUIRED);
                }

                foreach ($this->items as $i) {
                    if (!isset($i['name'])) {
                        throw new MonetaSdkException(self::EXCEPTION_REQUIRED_ITEM_PARAM . '"name"');
                    } else if (!isset($i['price'])) {
                        throw new MonetaSdkException(self::EXCEPTION_REQUIRED_ITEM_PARAM . '"price"');
                    } else if (!isset($i['quantity'])) {
                        throw new MonetaSdkException(self::EXCEPTION_REQUIRED_ITEM_PARAM . '"quantity"');
                    }
                }
                break;
            case false:
                if (!isset($this->customer['email'])) {
                    throw new MonetaSdkException(self::EXCEPTION_REQUIRED_CUSTOMER_PARAM . '"email"');
                }

                break;
            default:
                break;
        }
    }
}
